pub unsafe extern "C" fn pw_context_register_export_type(
context: *mut pw_context,
type_: *mut pw_export_type,
) -> c_intExpand description
register a type that can be exported on a context_proxy. This is usually used by extension modules
pub unsafe extern "C" fn pw_context_register_export_type(
context: *mut pw_context,
type_: *mut pw_export_type,
) -> c_intregister a type that can be exported on a context_proxy. This is usually used by extension modules