pub type pw_impl_module_init_func_t = Option<unsafe extern "C" fn(module: *mut pw_impl_module, args: *const c_char) -> c_int>;Expand description
Module init function signature
\param module A \ref pw_impl_module \param args Arguments to the module \return 0 on success, < 0 otherwise with an errno style error
A module should provide an init function with this signature. This function will be called when a module is loaded.
Aliased Type
pub enum pw_impl_module_init_func_t {
None,
Some(unsafe extern "C" fn(*mut pw_impl_module, *const i8) -> i32),
}